pub struct Interface<Ops>where
Ops: OpsT,{ /* private fields */ }Expand description
Collection of server-side notification handlers
Implementations
Sourceimpl<Ops> Interface<Ops>where
Ops: OpsT,
impl<Ops> Interface<Ops>where
Ops: OpsT,
Sourcepub fn notification<Msg>(&mut self, op: Ops, method: Notification<Msg>)
pub fn notification<Msg>(&mut self, op: Ops, method: Notification<Msg>)
Register a notification handler for the given operation. Panics if a
handler for the same op has already been registered.
Sourcepub async fn call_notification_with_borsh(
&self,
op: &Ops,
payload: &[u8],
) -> ServerResult<()>
pub async fn call_notification_with_borsh( &self, op: &Ops, payload: &[u8], ) -> ServerResult<()>
Dispatch a Borsh-encoded notification payload to the handler registered
for op, returning ServerError::NotFound if none exists.
Sourcepub async fn call_notification_with_serde_json(
&self,
op: &Ops,
payload: Value,
) -> ServerResult<()>
pub async fn call_notification_with_serde_json( &self, op: &Ops, payload: Value, ) -> ServerResult<()>
Dispatch a JSON notification payload to the handler registered for op,
returning ServerError::NotFound if none exists.