pub struct RpcClient<Ops, Id = Id64>{ /* private fields */ }Expand description
wRPC client capable of issuing requests and notifications and dispatching
server-side notifications over a WebSocket connection using either the
Borsh or JSON protocol. Ops is the application operation enum and Id
is the message identifier type.
Implementations
Sourceimpl<Ops, Id> RpcClient<Ops, Id>
impl<Ops, Id> RpcClient<Ops, Id>
Sourcepub fn new_with_encoding(
encoding: Encoding,
interface: Option<Arc<Interface<Ops>>>,
options: Options<'_>,
config: Option<WebSocketConfig>,
) -> Result<RpcClient<Ops, Id>>
pub fn new_with_encoding( encoding: Encoding, interface: Option<Arc<Interface<Ops>>>, options: Options<'_>, config: Option<WebSocketConfig>, ) -> Result<RpcClient<Ops, Id>>
Create new wRPC client connecting to the supplied URL
This function accepts the Encoding enum argument denoting the underlying
protocol that will be used by the client. Current variants supported
are:
Sourcepub fn new<T>(
interface: Option<Arc<Interface<Ops>>>,
options: Options<'_>,
config: Option<WebSocketConfig>,
) -> Result<RpcClient<Ops, Id>>
pub fn new<T>( interface: Option<Arc<Interface<Ops>>>, options: Options<'_>, config: Option<WebSocketConfig>, ) -> Result<RpcClient<Ops, Id>>
Create new wRPC client connecting to the supplied URL.
This function accepts a generic denoting the underlying protocol that will be used by the client. Current protocols supported are:
Sourcepub async fn connect(&self, options: ConnectOptions) -> ConnectResult<Error>
pub async fn connect(&self, options: ConnectOptions) -> ConnectResult<Error>
Connect to the target wRPC endpoint (websocket address)
Sourcepub fn ctl_multiplexer(&self) -> &Option<Multiplexer<Ctl>>
pub fn ctl_multiplexer(&self) -> &Option<Multiplexer<Ctl>>
Access the optional connect/disconnect Ctl event multiplexer
configured for this client, if any.
Sourcepub fn is_connected(&self) -> bool
pub fn is_connected(&self) -> bool
Test if the underlying WebSocket is currently open
Sourcepub fn set_url(&self, url: &str) -> Result<()>
pub fn set_url(&self, url: &str) -> Result<()>
Change the URL of the underlying WebSocket
(applicable only to the next connection).
Alternatively, the new URL can be supplied
in the connect() method using ConnectOptions.
Sourcepub fn configure(&self, config: WebSocketConfig)
pub fn configure(&self, config: WebSocketConfig)
Change the configuration of the underlying WebSocket. This method can be used to alter the configuration for the next connection.
Sourcepub fn trigger_abort(&self) -> Result<()>
pub fn trigger_abort(&self) -> Result<()>
Triggers a disconnection on the underlying WebSocket. This is intended for debug purposes only. Can be used to test application reconnection logic.