ConnectResult

Type Alias ConnectResult 

pub type ConnectResult<E> = Result<Option<Receiver<Result<(), Error>>>, E>;
Result of a connect attempt. On success yields Some(receiver) when the caller did not block on the connection (the receiver fires once connected), or None when the connect call blocked until the connection was established.

Aliased Type

pub enum ConnectResult<E> {
    Ok(Option<Receiver<Result<(), Error>>>),
    Err(E),
}

Variants

1.0.0

Ok(Option<Receiver<Result<(), Error>>>)

Contains the success value

1.0.0

Err(E)

Contains the error value