Module error

Module error 

Common Error definitions used by both super::client and super::server modules.

Enums

Error
Errors shared by the wRPC client and server message-handling layers.
ServerError
ServerError enum is used by both Server and Client and represents errors returned by server-side handlers. This enum is also serialized and transported to the client when using the Borsh protocol (as such, this mostly contains pure enum values).