pub enum ServerError {
}Expand description
ServerError enum is used by both Server and Client and
represents errors returned by server-side handlers. This enum
is also serialized and transported to the client when using
the Borsh protocol (as such, this mostly contains pure enum
values).
Variants
Close
The connection has been closed.
Timeout
The RPC call did not complete within the allotted time.
NoData
No data was available where data was expected.
NotFound
No handler was registered for the requested RPC method.
PoisonError
A lock was poisoned by a panic in another thread.
NonBorshRequest
The request was expected to use the Borsh protocol but did not.
NonSerdeRequest
The request was expected to use the serde/JSON protocol but did not.
ReqSerialize
The request could not be serialized.
ReqDeserialize
The request could not be deserialized.
RespSerialize
The response could not be serialized.
NotificationDeserialize(String)
A notification payload could not be deserialized.
RespDeserialize(String)
A response payload could not be deserialized.
Data(Vec<u8>)
Opaque binary error payload.
Text(String)
Free-form textual error message.
WebSocketError(String)
Underlying WebSocket error
ReceiveChannelRx
Failure receiving from an internal receiver channel.
ReceiveChannelTx
Failure sending to an internal receiver channel.