pub enum WebSocketError {
Show 15 variants
Other(String),
Listen(String),
ConnectionTimeout,
MalformedHandshake,
MalformedMessage,
NegotiationFailure,
NegotiationFailureWithReason(String),
ResponseChannelError(SendError<Message>),
WebSocketError(Box<Error>),
AbnormalClose,
ServerClose,
Stop(String),
Done(String),
Join(String),
IoError(Error),
}Expand description
Errors produced by the WebSocketServer.
Variants
Other(String)
A generic, miscellaneous error carrying a descriptive message.
Listen(String)
The server failed to bind and listen on the requested address.
ConnectionTimeout
Indicates that no messages have been received within the specified timeout period
MalformedHandshake
Indicates that the data received is not a valid handshake message
MalformedMessage
Indicates that the data received is not a valid or acceptable message
NegotiationFailure
Indicates handler negotiation failure This error code is reserved for structs implementing WebSocket handler.
NegotiationFailureWithReason(String)
Indicates handler negotiation failure with a specific reason This error code is reserved for structs implementing WebSocket handler.
ResponseChannelError(SendError<Message>)
Error sending response via the tokio MPSC response channel
WebSocketError(Box<Error>)
WebSocket error produced by the underlying Tungstenite WebSocket crate
AbnormalClose
Connection terminated abnormally
ServerClose
Server closed connection
Stop(String)
Failure while signaling the listener to stop.
Done(String)
Failure while signaling that the listener has finished shutting down.
Join(String)
Failure while waiting for the listener to shut down.
IoError(Error)
An underlying I/O error.