MsgT

Trait MsgT 

pub trait MsgT:
    BorshSerialize
    + BorshDeserialize
    + Serialize
    + DeserializeOwned
    + Send
    + Sync
    + 'static { }
Marker trait bundling the bounds required of an RPC message payload type (request, response or notification): it must be serializable via both Borsh and Serde and shareable across threads.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors