Trait constraints for RPC methods (Ops) and message (Req,Resp,Msg).
Traits
- MsgT
- Marker trait bundling the bounds required of an RPC message payload type (request, response or notification): it must be serializable via both Borsh and Serde and shareable across threads.
- OpsT
- Marker trait bundling the bounds required of an RPC operation (method) id type: it must be hashable and comparable for dispatch, serializable via both Borsh and Serde, and shareable across threads.